@@ -15,7 +15,7 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.1
+    \version   0.7.5.2
     \date      JAN 2021
  */
 
@@ -36,9 +36,8 @@
  */
 namespace ProSHADE_internal_sphericalHarmonics
 {
-    void allocateComputationMemory                    ( proshade_unsign band, proshade_double*& inputReal, proshade_double*& inputImag,
-                                                        proshade_double*& outputReal,
-                                                        proshade_double*& outputImag, double*& shWeights, double*& tableSpaceHelper, fftw_complex*& workspace );
+    void allocateComputationMemory                    ( proshade_unsign band, proshade_double*& inputReal, proshade_double*& inputImag, proshade_double*& outputReal,
+                                                        proshade_double*& outputImag, double*& shWeights, double**& tableSpace, double*& tableSpaceHelper, fftw_complex*& workspace );
     void placeWithinWorkspacePointers                 ( fftw_complex*& workspace, proshade_unsign oDim, proshade_double*& rres, proshade_double*& ires,
                                                         proshade_double*& fltres, proshade_double*& scratchpad );
     void initialiseFFTWPlans                          ( proshade_unsign band, fftw_plan& fftPlan, fftw_plan& dctPlan, proshade_double*& inputReal,
@@ -46,7 +45,8 @@ namespace ProSHADE_internal_sphericalHarmonics
                                                         proshade_double*& scratchpad );
     void releaseSphericalMemory                       ( proshade_double*& inputReal, proshade_double*& inputImag, proshade_double*& outputReal,
                                                         proshade_double*& outputImag, double*& tableSpaceHelper, double**& tableSpace,
-                                                        double*& shWeights, fftw_complex*& workspace, fftw_plan& fftPlan, fftw_plan& dctPlan );
+                                                        double*& shWeights, fftw_complex*& workspace, fftw_plan& fftPlan, fftw_plan& dctPlan,
+                                                        proshade_unsign band );
     void initialiseAllMemory                          ( proshade_unsign band, proshade_double*& inputReal, proshade_double*& inputImag,
                                                         proshade_double*& outputReal,
                                                         proshade_double*& outputImag, double*& shWeights, double**& tableSpace,
